@@ -20,7 +20,7 @@ use std::ops::Deref;
 /// ```
 /// use refid::RefId;
 /// use std::collections::HashSet;
-/// fn count_distinct<T: std::fmt::Debug>(slice: &[&T]) -> usize {
+/// fn count_distinct<T>(slice: &[&T]) -> usize {
 ///     let mut counted: HashSet<RefId<&T>> = HashSet::new();
 ///     let mut count: usize = 0;
 ///     for item in slice {
@@ -35,7 +35,7 @@ use std::ops::Deref;
 /// let v3 = "X".to_string();
 /// assert_eq!(count_distinct(&vec![&v1, &v2, &v1, &v3]), 3);
 /// ```
-#[derive(Clone)]
+#[derive(Clone, Copy)]
 pub struct RefId<T: ?Sized + Deref>(
     /// inner value (reference or smart pointer)
     pub T,
@@ -135,7 +135,7 @@ mod tests {
     #[test]
     fn test_hash_set() {
         use std::collections::HashSet;
-        fn count_distinct<T: std::fmt::Debug>(slice: &[&T]) -> usize {
+        fn count_distinct<T>(slice: &[&T]) -> usize {
             let mut counted: HashSet<RefId<&T>> = HashSet::new();
             let mut count: usize = 0;
             for item in slice {
